Package: robmixglm
Type: Package
Title: Robust Generalized Linear Models (GLM) using Mixtures
Version: 1.2-5
Date: 2025-10-31
Authors@R: c(person("Ken","Beath",email="ken@kjbeath.id.au", role=c("aut","cre")))
Maintainer: Ken Beath <ken@kjbeath.id.au>
Contact: Ken Beath <ken@kjbeath.id.au>
Author: Ken Beath [aut, cre]
Description: Robust generalized linear models (GLM) using a mixture method, as described in Beath (2018) <doi:10.1080/02664763.2017.1414164>. This assumes that the data are a mixture of standard observations, being a generalised linear model, and outlier observations from an overdispersed generalized linear model. The overdispersed linear model is obtained by including a normally distributed random effect in the linear predictor of the generalized linear model.
Depends: R(>= 3.2.0)
Suggests: R.rsp, robustbase, lattice, forward
VignetteBuilder: R.rsp
Imports: fastGHQuad, stats, bbmle, VGAM, actuar, Rcpp (>= 0.12.15),
        methods, boot, numDeriv, parallel, doParallel, foreach, doRNG,
        MASS
LazyLoad: yes
LazyData: yes
NeedsCompilation: yes
License: GPL (>= 2)
LinkingTo: Rcpp
Packaged: 2025-10-31 06:21:35 UTC; kjbea
Repository: CRAN
Date/Publication: 2025-10-31 09:50:02 UTC
Built: R 4.6.0; x86_64-apple-darwin20; 2026-04-27 19:53:55 UTC; unix
Archs: robmixglm.so.dSYM
