Package: robmixglm
Type: Package
Title: Robust Generalized Linear Models (GLM) using Mixtures
Version: 1.2-8
Date: 2026-07-02
Authors@R: c(person("Ken","Beath",email="ken@kjbeath.id.au", role=c("aut","cre")))
Maintainer: Ken Beath <ken@kjbeath.id.au>
Contact: Ken Beath <ken@kjbeath.id.au>
Author: Ken Beath [aut, cre]
Description: Robust generalized linear models (GLM) using a mixture method, as described in Beath (2018) <doi:10.1080/02664763.2017.1414164>. This assumes that the data are a mixture of standard observations, being a generalised linear model, and outlier observations from an overdispersed generalized linear model. The overdispersed linear model is obtained by including a normally distributed random effect in the linear predictor of the generalized linear model.
Depends: R(>= 3.2.0)
Suggests: R.rsp, robustbase, lattice, forward
VignetteBuilder: R.rsp
Imports: fastGHQuad, stats, bbmle, VGAM, actuar, Rcpp (>= 0.12.15),
        methods, boot, numDeriv, parallel, MASS
LazyLoad: yes
LazyData: yes
NeedsCompilation: yes
License: GPL (>= 2)
LinkingTo: Rcpp
Packaged: 2026-07-02 09:43:45 UTC; kenbeath
Repository: CRAN
Date/Publication: 2026-07-02 10:00:03 UTC
