# Generated by using Rcpp::compileAttributes() -> do not edit by hand
# Generator token: 10BE3573-1514-4C36-9D1C-5A225CD40393

llrandpoiscpp <- function(y, lp, tau2, gh) {
    .Call(`_robmixglm_llrandpoiscpp`, y, lp, tau2, gh)
}

llrandtruncpoiscpp <- function(y, lp, tau2, gh) {
    .Call(`_robmixglm_llrandtruncpoiscpp`, y, lp, tau2, gh)
}

llrandgammacpp <- function(y, lp, tau2, phi, gh) {
    .Call(`_robmixglm_llrandgammacpp`, y, lp, tau2, phi, gh)
}

llrandbinomcpp <- function(y, lp, tau2, gh) {
    .Call(`_robmixglm_llrandbinomcpp`, y, lp, tau2, gh)
}

